yell/notifier
OTP Actor that sends SSDP multicast notifications to advertise a service
Types
Values
pub fn loop(actor: actor.Started(Sender), interval: Int) -> Nil
Start sending Alive notifications at a fixed interval (in milliseconds). Call this once to begin periodic notifications.
pub fn send(
actor: actor.Started(Sender),
status: yell.Status,
) -> Nil
Send a single notification with the specified status. Will stop any running loops.
pub fn start(
service: yell.Service,
) -> Result(actor.Started(Sender), actor.StartError)
Start the notifier actor for a service. Returns an object that can be used to send messages to the actor.
pub fn stop(actor: actor.Started(Sender)) -> Nil
Send a ByeBye notification and stop recurrent messages.