yell/replier
OTP Actor that replies to SSDP discovery requests
Types
A builder for the actor. Create with new() and optionally subscribe to discovery messages
with subscribe() before calling start()
pub opaque type Builder
A discovery message received on the SSDP multicast port
ip- The source IP address of the discovery requestcontent- The parsed discovery message
pub type Message {
Message(ip: glip.IpAddress, content: yell.Message)
}
Constructors
-
Message(ip: glip.IpAddress, content: yell.Message)
Values
pub fn new(
service: yell.Service,
addr: glip.IpAddress,
) -> Builder
Create a replier for a service.
service- The service to advertiseaddr- The local IP address to bind to
pub fn start(
replier: Builder,
) -> Result(actor.Started(Nil), actor.StartError)
Start the replier actor. It will listen for discovery requests on the SSDP multicast address and automatically send replies for matching services.